//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Tile](../index.md)/[Companion](index.md)/[MAX_TILE_CODE](-m-a-x_-t-i-l-e_-c-o-d-e.md)

# MAX_TILE_CODE

[common]\
const val [MAX_TILE_CODE](-m-a-x_-t-i-l-e_-c-o-d-e.md): [Int](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)

牌编号最大值
